.. AxoDen documentation master file, created by
   sphinx-quickstart on Thu May  9 11:39:30 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AxoDen's documentation!
==================================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Module documentation
--------------------

.. toctree::
   :maxdepth: 2

   axoden
   volume_projections
   gui

